@@ -16,18 +16,16 @@
 import json
 import sys
 
-from cliff import command
-from cliff import lister
-from cliff import show
-from openstackclient.common import exceptions
-from openstackclient.common import utils as osc_utils
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils as osc_utils
 from oslo_log import log as logging
 
 from saharaclient.osc.v1 import utils
 
-CT_FIELDS = ['id', 'name', 'plugin_name', 'version', 'description',
+CT_FIELDS = ['id', 'name', 'plugin_name', 'plugin_version', 'description',
              'node_groups', 'anti_affinity', 'use_autoconfig', 'is_default',
-             'is_protected', 'is_public']
+             'is_protected', 'is_public', 'domain_name']
 
 
 def _format_node_groups_list(node_groups):
@@ -36,7 +34,7 @@ def _format_node_groups_list(node_groups):
 
 
 def _format_ct_output(data):
-    data['version'] = data.pop('hadoop_version')
+    data['plugin_version'] = data.pop('hadoop_version')
     data['node_groups'] = _format_node_groups_list(data['node_groups'])
     data['anti_affinity'] = osc_utils.format_list(data['anti_affinity'])
 
@@ -59,11 +57,11 @@ def _configure_node_groups(node_groups, client):
         raise exceptions.CommandError('Node groups with the same plugins '
                                       'and versions must be specified')
 
-    plugin, version = plugins_versions.pop()
-    return plugin, version, node_groups
+    plugin, plugin_version = plugins_versions.pop()
+    return plugin, plugin_version, node_groups
 
 
-class CreateClusterTemplate(show.ShowOne):
+class CreateClusterTemplate(command.ShowOne):
     """Creates cluster template"""
 
     log = logging.getLogger(__name__ + ".CreateClusterTemplate")
@@ -134,6 +132,12 @@ class CreateClusterTemplate(show.ShowOne):
             metavar='<filename>',
             help='JSON representation of the cluster template configs'
         )
+        parser.add_argument(
+            '--domain-name',
+            metavar='<domain-name>',
+            help='Domain name for instances of this cluster template. This '
+                 'option is available if \'use_designate\' config is True'
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -180,20 +184,21 @@ class CreateClusterTemplate(show.ShowOne):
                         'An error occurred when reading '
                         'shares from file %s: %s' % (parsed_args.shares, e))
 
-            plugin, version, node_groups = _configure_node_groups(
+            plugin, plugin_version, node_groups = _configure_node_groups(
                 parsed_args.node_groups, client)
 
             data = client.cluster_templates.create(
                 name=parsed_args.name,
                 plugin_name=plugin,
-                hadoop_version=version,
+                hadoop_version=plugin_version,
                 description=parsed_args.description,
                 node_groups=node_groups,
                 use_autoconfig=parsed_args.autoconfig,
                 cluster_configs=configs,
                 shares=shares,
                 is_public=parsed_args.public,
-                is_protected=parsed_args.protected
+                is_protected=parsed_args.protected,
+                domain_name=parsed_args.domain_name
             ).to_dict()
 
         _format_ct_output(data)
@@ -202,7 +207,7 @@ class CreateClusterTemplate(show.ShowOne):
         return self.dict2columns(data)
 
 
-class ListClusterTemplates(lister.Lister):
+class ListClusterTemplates(command.Lister):
     """Lists cluster templates"""
 
     log = logging.getLogger(__name__ + ".ListClusterTemplates")
@@ -222,8 +227,8 @@ class ListClusterTemplates(lister.Lister):
         )
 
         parser.add_argument(
-            '--version',
-            metavar="<version>",
+            '--plugin-version',
+            metavar="<plugin_version>",
             help="List cluster templates with specific version of the "
                  "plugin"
         )
@@ -243,8 +248,8 @@ class ListClusterTemplates(lister.Lister):
         search_opts = {}
         if parsed_args.plugin:
             search_opts['plugin_name'] = parsed_args.plugin
-        if parsed_args.version:
-            search_opts['hadoop_version'] = parsed_args.version
+        if parsed_args.plugin_version:
+            search_opts['hadoop_version'] = parsed_args.plugin_version
 
         data = client.cluster_templates.list(search_opts=search_opts)
 
@@ -255,12 +260,12 @@ class ListClusterTemplates(lister.Lister):
             columns = ('name', 'id', 'plugin_name', 'hadoop_version',
                        'node_groups', 'description')
             column_headers = utils.prepare_column_headers(
-                columns, {'hadoop_version': 'version'})
+                columns, {'hadoop_version': 'plugin_version'})
 
         else:
             columns = ('name', 'id', 'plugin_name', 'hadoop_version')
             column_headers = utils.prepare_column_headers(
-                columns, {'hadoop_version': 'version'})
+                columns, {'hadoop_version': 'plugin_version'})
 
         return (
             column_headers,
@@ -274,7 +279,7 @@ class ListClusterTemplates(lister.Lister):
         )
 
 
-class ShowClusterTemplate(show.ShowOne):
+class ShowClusterTemplate(command.ShowOne):
     """Display cluster template details"""
 
     log = logging.getLogger(__name__ + ".ShowClusterTemplate")
@@ -329,7 +334,7 @@ class DeleteClusterTemplate(command.Command):
                 'successfully.\n'.format(ct=ct))
 
 
-class UpdateClusterTemplate(show.ShowOne):
+class UpdateClusterTemplate(command.ShowOne):
     """Updates cluster template"""
 
     log = logging.getLogger(__name__ + ".UpdateClusterTemplate")
@@ -426,6 +431,13 @@ class UpdateClusterTemplate(show.ShowOne):
             metavar='<filename>',
             help='JSON representation of the cluster template configs'
         )
+        parser.add_argument(
+            '--domain-name',
+            metavar='<domain-name>',
+            default=None,
+            help='Domain name for instances of this cluster template. This '
+                 'option is available if \'use_designate\' config is True'
+        )
         parser.set_defaults(is_public=None, is_protected=None,
                             use_autoconfig=None)
         return parser
@@ -448,9 +460,9 @@ class UpdateClusterTemplate(show.ShowOne):
             data = client.cluster_templates.update(
                 ct_id, **template).to_dict()
         else:
-            plugin, version, node_groups = None, None, None
+            plugin, plugin_version, node_groups = None, None, None
             if parsed_args.node_groups:
-                plugin, version, node_groups = _configure_node_groups(
+                plugin, plugin_version, node_groups = _configure_node_groups(
                     parsed_args.node_groups, client)
 
             configs = None
@@ -476,14 +488,15 @@ class UpdateClusterTemplate(show.ShowOne):
             update_dict = utils.create_dict_from_kwargs(
                 name=parsed_args.name,
                 plugin_name=plugin,
-                hadoop_version=version,
+                hadoop_version=plugin_version,
                 description=parsed_args.description,
                 node_groups=node_groups,
                 use_autoconfig=parsed_args.use_autoconfig,
                 cluster_configs=configs,
                 shares=shares,
                 is_public=parsed_args.is_public,
-                is_protected=parsed_args.is_protected
+                is_protected=parsed_args.is_protected,
+                domain_name=parsed_args.domain_name
             )
 
             data = client.cluster_templates.update(
