@@ -15,7 +15,7 @@
 
 
 import mock
-from openstackclient.tests import utils
+from osc_lib.tests import utils
 
 
 class TestDataProcessing(utils.TestCommand):
